package net.javajigi.user.web.coc;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import net.javajigi.user.UserNotFoundException;
import net.javajigi.user.model.User;
import net.javajigi.user.service.UserService;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.support.MessageSourceAccessor;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.multiaction.MultiActionController;

public class UserController extends MultiActionController {
	private static Log log = LogFactory.getLog(UserController.class);

	private UserService userService;

	private MessageSourceAccessor messageSource;

	public void setUserService(UserService userService) {
		this.userService = userService;
	}

	@Autowired
	public void setMessageSource(MessageSourceAccessor messageSource) {
		this.messageSource = messageSource;
	}

	public ModelAndView list(HttpServletRequest request, HttpServletResponse response) throws Exception {
		List<User> userList = userService.findUserList();

		ModelAndView mav = new ModelAndView();
		mav.addObject("users", userList);

		return mav;
	}

	public ModelAndView addForm(HttpServletRequest request, HttpServletResponse response) throws Exception {
		User loginUser = null;
		if( request.getSession().getAttribute("user") != null ) {
			loginUser = (User)request.getSession().getAttribute("user");
		}

		ModelAndView mav = new ModelAndView("user/add");
		mav.addObject("loginUser", loginUser);

		return mav;
	}	
	
	public ModelAndView add(HttpServletRequest request, HttpServletResponse response) throws Exception {
		User user = new User();
		bind(request, user);
		
		userService.addUser(user);

		return new ModelAndView("redirect:/user/list.do");
	}	

	public ModelAndView view(HttpServletRequest request, HttpServletResponse response) throws Exception {
		ModelAndView mav = new ModelAndView();
		try {
			String userId = request.getParameter("userId");
			User user = userService.findUser(userId);
			mav.addObject("user", user);

			return mav;
		} catch (UserNotFoundException e) {
			String errorMessage = messageSource.getMessage(e.getErrorCode(), new Object[] { e.getUserId() });

			if (log.isDebugEnabled()) {
				log.debug("Error Message : " + errorMessage);
			}

			mav.setViewName("/common/error");
			mav.addObject("errorMessage", errorMessage);
			mav.addObject("forwardUrl", "/user/list.do");

			return mav;
		}
	}
	
	public ModelAndView editForm(HttpServletRequest request, HttpServletResponse response) throws Exception {
		String userId = request.getParameter("userId");
		User user = userService.findUser(userId);
		
		ModelAndView mav = new ModelAndView("user/edit");
		mav.addObject("user", user);

		return mav;
	}
	
	public ModelAndView edit(HttpServletRequest request, HttpServletResponse response) throws Exception {
		User user = new User();
		bind(request, user);
		
		userService.updateUser(user);

		return new ModelAndView("redirect:/user/list.do");
	}	
	
	public ModelAndView remove(HttpServletRequest request, HttpServletResponse response) throws Exception {
		String userId = request.getParameter("userId");
		
		userService.removeUser(userId);

		return new ModelAndView("redirect:/user/list.do");
	}	
}
