package net.javajigi.user.dao;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import net.javajigi.AbstractTests;
import net.javajigi.user.model.RoleType;
import net.javajigi.user.model.User;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.junit.Before;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

@ContextConfiguration(locations = { "/applicationContext.xml", "/applicationContext-user.xml" })
public class SimpleJdbcUserTest extends AbstractTests {
	private static Log log = LogFactory.getLog(SimpleJdbcUserTest.class);

	@Autowired
	private UserDao userDAO;

	public void setUserDAO(UserDao userDAO) {
		this.userDAO = userDAO;
	}

	@Before
	public void setUp() {
		deleteFromTables("USER");
	}

	@Test
	public void findUser() throws Exception {
		User user = populateUser();
		assertEquals(1, userDAO.insert(user));

		User resultUser = userDAO.findUser(user.getUserId());
		assertNotNull(resultUser);

		if (log.isDebugEnabled()) {
			log.debug("User : " + user);
		}
	}

	private User populateUser() {
		User user = new User();
		user.setUserId("testuser");
		user.setPassword("password");
		user.setName("jaesung");
		user.setEmail("javajigi@gmail.com");
		user.setRoleType(RoleType.NORMAL);

		return user;
	}

	@Test
	public void addAndFindAndDeleteUser() throws Exception {
		User user = populateUser();

		assertEquals(1, userDAO.insert(user));
		User dbUser = userDAO.findUser(user.getUserId());

		assertEquals(user, dbUser);
	}

	@Test
	public void findAndUpdateUser() throws Exception {
		User user = populateUser();

		assertEquals(1, userDAO.insert(user));

		user.setName("Park Jae Sung");
		user.setPassword("pass");
		user.setEmail("javajigi@javajigi.net");
		user.setRoleType(RoleType.ADMIN);

		assertEquals(1, userDAO.update(user));

		User dbUser = userDAO.findUser(user.getUserId());

		assertNotNull(dbUser);
	}
}
