package net.javajigi.user.dao;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import net.javajigi.user.model.RoleType;
import net.javajigi.user.model.User;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;

@RunWith(SpringJUnit4ClassRunner.class)
@ContextConfiguration(locations={"/applicationContext.xml", "/applicationContext-jdbc.xml", "/applicationContext-user.xml"})
public class UserDaoWithJDBCTest {
	private UserDao userDao;
	
	@Autowired
	public void setUserDao(UserDao userDao) {
		this.userDao = userDao;
	}

	private User populateUser() {
		User user = new User();
		user.setUserId("testuser");
		user.setPassword("password");
		user.setName("jaesung");
		user.setEmail("javajigi@gmail.com");
		user.setRoleType(RoleType.NORMAL);

		return user;
	}

	@Test
	public void addAndFindAndDeleteUser() throws Exception {
		User user = populateUser();

		try {
			assertEquals(1, userDao.insert(user));

			User dbUser = userDao.findUser(user.getUserId());

			assertEquals(user, dbUser);
		} finally {
			assertEquals(1, userDao.delete(user.getUserId()));
		}
	}

	@Test
	public void findAndUpdateUser() throws Exception {
		User user = populateUser();

		try {
			assertEquals(1, userDao.insert(user));

			user.setName("Park Jae Sung");
			user.setPassword("pass");
			user.setEmail("javajigi@javajigi.net");
			user.setRoleType(RoleType.ADMIN);

			assertEquals(1, userDao.update(user));

			User dbUser = userDao.findUser(user.getUserId());

			assertNotNull(dbUser);
		} finally {
			assertEquals(1, userDao.delete(user.getUserId()));
		}
	}
}
