package net.javajigi.user.web;

import net.javajigi.user.model.AdminMockUser;
import net.javajigi.user.model.RoleType;
import net.javajigi.user.model.User;
import net.javajigi.user.service.UserService;
import net.javajigi.user.web.coc.UserController;

import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Before;
import org.junit.Test;
import org.springframework.mock.web.MockHttpServletRequest;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.support.WebBindingInitializer;
import org.springframework.web.context.request.WebRequest;

public class RoleTypeEditorTest {
	private Mockery context;
	private UserService userService;
	
	@Before public void setup() {
		context = new Mockery();
		userService = context.mock(UserService.class);
	}
	
	@Test public void roleTypeAdmin() throws Exception {
		final User adminUser = new AdminMockUser();
		MockHttpServletRequest request = new MockHttpServletRequest();
		request.addParameter("userId", adminUser.getUserId());
		request.addParameter("password", adminUser.getPassword());
		request.addParameter("name", adminUser.getName());
		request.addParameter("email", adminUser.getEmail());
		request.addParameter("roleType", "ADMIN");
		
		context.checking(new Expectations() {{
			one(userService).addUser(adminUser); will(returnValue(1));
		}});
		
		UserController controller = new UserController();
		controller.setWebBindingInitializer(new WebBindingInitializer() {
			public void initBinder(WebDataBinder binder, WebRequest request) {
				binder.registerCustomEditor(RoleType.class, new RoleTypeEditor());
			}
		});
		controller.setUserService(userService);
		
		controller.add(request, null);
	}
	
	@Test public void roleTypeUser() throws Exception {
		final User normalUser = new AdminMockUser();
		MockHttpServletRequest request = new MockHttpServletRequest();
		request.addParameter("userId", normalUser.getUserId());
		request.addParameter("password", normalUser.getPassword());
		request.addParameter("name", normalUser.getName());
		request.addParameter("email", normalUser.getEmail());
		request.addParameter("roleType", "NORMAL");
		
		context.checking(new Expectations() {{
			one(userService).addUser(normalUser); will(returnValue(1));
		}});
		
		UserController controller = new UserController();
		controller.setWebBindingInitializer(new WebBindingInitializer() {
			public void initBinder(WebDataBinder binder, WebRequest request) {
				binder.registerCustomEditor(RoleType.class, new RoleTypeEditor());
			}
		});
		controller.setUserService(userService);
		
		controller.add(request, null);
	}
	
	@Test public void roleTypeUserNULL() throws Exception {
		final User normalUser = new AdminMockUser();
		MockHttpServletRequest request = new MockHttpServletRequest();
		request.addParameter("userId", normalUser.getUserId());
		request.addParameter("password", normalUser.getPassword());
		request.addParameter("name", normalUser.getName());
		request.addParameter("email", normalUser.getEmail());
		String roleType = null;
		request.addParameter("roleType", roleType);
		
		context.checking(new Expectations() {{
			one(userService).addUser(normalUser); will(returnValue(1));
		}});
		
		UserController controller = new UserController();
		controller.setWebBindingInitializer(new WebBindingInitializer() {
			public void initBinder(WebDataBinder binder, WebRequest request) {
				binder.registerCustomEditor(RoleType.class, new RoleTypeEditor());
			}
		});
		controller.setUserService(userService);
		
		controller.add(request, null);
	}	
}
